==> tiendaparamipyme-1.0.0.tar.gz: tiendaparamipyme/js/comunas.js <==
var comunas = {
    "Antofagasta": [
    "Antofagasta",
    "Calama",
    "María Elena",
    "Mejillones",
    "Ollagüe",
    "San Pedro de Atacama",
    "Sierra Gorda",
    "Taltal",
    "Tocopilla",
    ],
    "Araucanía": [
    "Angol",
    "Carahue",
    "Cholchol",
    "Collipulli",
    "Cunco",
    "Curacautín",
    "Curarrehue",
    "Ercilla",
    "Freire",
    "Galvarino",
    "Gorbea",
    "Lautaro",
    "Loncoche",
    "Lonquimay",
    "Los Sauces",
    "Lumaco",
    "Melipeuco",
    "Nueva Imperial",
    "Padre Las Casas",
    "Perquenco",
    "Pitrufquén",
    "Pucón",
    "Purén",
    "Renaico",
    "Saavedra",
    "Temuco",
    "Teodoro Schmidt",
    "Toltén",
    "Traiguén",
    "Victoria",
    "Vilcún",
    "Villarrica",
    ],
    "Arica y Parinacota": [
    "Arica",
    "Camarones",
    "General Lagos",
    "Putre",
    ],
    "Atacama": [
    "Alto del Carmen",
    "Caldera",
    "Chañaral",
    "Copiapó",
    "Diego de Almagro",
    "Freirina",
    "Huasco",
    "Tierra Amarilla",
    "Vallenar",
    ],
    "Aysén": [
    "Aysén",
    "Chile Chico",
    "Cisnes",
    "Cochrane",
    "Coyhaique",
    "Guaitecas",
    "Lago Verde",
    "O'Higgins",
    "Río Ibáñez",
    "Tortel",
    ],
    "Biobío": [
    "Alto Biobío",
    "Antuco",
    "Arauco",
    "Bulnes",
    "Cabrero",
    "Cañete",
    "Chiguayante",
    "Chillán",
    "Chillán Viejo",
    "Cobquecura",
    "Coelemu",
    "Coihueco",
    "Concepción",
    "Contulmo",
    "Coronel",
    "Curanilahue",
    "El Carmen",
    "Florida",
    "Hualpén",
    "Hualqui",
    "Laja",
    "Lebu",
    "Los Álamos",
    "Los Ángeles",
    "Lota",
    "Mulchén",
    "Nacimiento",
    "Negrete",
    "Ninhue",
    "Ñiquén",
    "Pemuco",
    "Penco",
    "Pinto",
    "Portezuelo",
    "Quilaco",
    "Quilleco",
    "Quillón",
    "Quirihue",
    "Ránquil",
    "San Carlos",
    "San Fabián",
    "San Ignacio",
    "San Nicolás",
    "San Pedro de la Paz",
    "San Rosendo",
    "Santa Bárbara",
    "Santa Juana",
    "Talcahuano",
    "Tirúa",
    "Tomé",
    "Treguaco",
    "Tucapel",
    "Yumbel",
    "Yungay"
    ],
    "Coquimbo": [
    "Andacollo",
    "Canela",
    "Combarbalá",
    "Coquimbo",
    "Illapel",
    "La Higuera",
    "La Serena",
    "Los Vilos",
    "Monte Patria",
    "Ovalle",
    "Paihuano",
    "Punitaqui",
    "Río Hurtado",
    "Salamanca",
    "Vicuña",
    ],
    "O'Higgins": [
    "Chépica",
    "Chimbarongo",
    "Codegua",
    "Coínco",
    "Coltauco",
    "Doñihue",
    "Graneros",
    "La Estrella",
    "Las Cabras",
    "Litueche",
    "Lolol",
    "Machalí",
    "Malloa",
    "Marchigüe",
    "Nancagua",
    "Navidad",
    "Olivar",
    "Palmilla",
    "Paredones",
    "Peralillo",
    "Peumo",
    "Pichidegua",
    "Pichilemu",
    "Placilla",
    "Pumanque",
    "Quinta de Tilcoco",
    "Rancagua",
    "Rengo",
    "Requínoa",
    "San Fernando",
    "San Francisco de Mostazal",
    "San Vicente de Tagua Tagua",
    "Santa Cruz",
    ],
    "Los Lagos": [
    "Ancud",
    "Calbuco",
    "Castro",
    "Chaitén",
    "Chonchi",
    "Cochamó",
    "Curaco de Vélez",
    "Dalcahue",
    "Fresia",
    "Frutillar",
    "Futaleufú",
    "Hualaihué",
    "Llanquihue",
    "Los Muermos",
    "Maullín",
    "Osorno",
    "Palena",
    "Puerto Montt",
    "Puerto Octay",
    "Puerto Varas",
    "Puqueldón",
    "Purranque",
    "Puyehue",
    "Queilén",
    "Quellón",
    "Quemchi",
    "Quinchao",
    "Río Negro",
    "San Juan de la Costa",
    "San Pablo",
    ],
    "Los Ríos": [
    "Corral",
    "Futrono",
    "La Unión",
    "Lago Ranco",
    "Lanco",
    "Los Lagos",
    "Máfil",
    "Mariquina",
    "Paillaco",
    "Panguipulli",
    "Río Bueno",
    "Valdivia",
    ],
    "Magallanes": [
    "Antártica",
    "Cabo de Hornos",
    "Laguna Blanca",
    "Natales",
    "Porvenir",
    "Primavera",
    "Punta Arenas",
    "Río Verde",
    "San Gregorio",
    "Timaukel",
    "Torres del Paine",
    ],
    "Maule": [
    "Cauquenes",
    "Chanco",
    "Colbún",
    "Constitución",
    "Curepto",
    "Curicó",
    "Empedrado",
    "Hualañé",
    "Licantén",
    "Linares",
    "Longaví",
    "Maule",
    "Molina",
    "Parral",
    "Pelarco",
    "Pelluhue",
    "Pencahue",
    "Rauco",
    "Retiro",
    "Río Claro",
    "Romeral",
    "Sagrada Familia",
    "San Clemente",
    "San Javier de Loncomilla",
    "San Rafael",
    "Talca",
    "Teno",
    "Vichuquén",
    "Villa Alegre",
    "Yerbas Buenas",
    ],
    "Región Metropolitana": [
    "Alhué",
    "Buin",
    "Calera de Tango",
    "Cerrillos",
    "Cerro Navia",
    "Colina",
    "Conchalí",
    "Curacaví",
    "El Bosque",
    "El Monte",
    "Estación Central",
    "Huechuraba",
    "Independencia",
    "Isla de Maipo",
    "La Cisterna",
    "La Florida",
    "La Granja",
    "La Pintana",
    "La Reina",
    "Lampa",
    "Las Condes",
    "Lo Barnechea",
    "Lo Espejo",
    "Lo Prado",
    "Macul",
    "Maipú",
    "María Pinto",
    "Melipilla",
    "Ñuñoa",
    "Padre Hurtado",
    "Paine",
    "Pedro Aguirre Cerda",
    "Peñaflor",
    "Peñalolén",
    "Pirque",
    "Providencia",
    "Pudahuel",
    "Puente Alto",
    "Quilicura",
    "Quinta Normal",
    "Recoleta",
    "Renca",
    "San Bernardo",
    "San Joaquín",
    "San José de Maipo",
    "San Miguel",
    "San Pedro",
    "San Ramón",
    "Santiago",
    "Talagante",
    "Tiltil",
    "Vitacura",
    ],
    "Tarapacá": [
    "Alto Hospicio",
    "Camiña",
    "Colchane",
    "Huara",
    "Iquique",
    "Pica",
    "Pozo Almonte",
    ],
    "Valparaíso": [
    "Algarrobo",
    "Cabildo",
    "Calle Larga",
    "Cartagena",
    "Casablanca",
    "Catemu",
    "Concón",
    "El Quisco",
    "El Tabo",
    "Hijuelas",
    "Isla de Pascua",
    "Juan Fernández",
    "La Calera",
    "La Cruz",
    "La Ligua",
    "Limache",
    "Llaillay",
    "Los Andes",
    "Nogales",
    "Olmué",
    "Panquehue",
    "Papudo",
    "Petorca",
    "Puchuncaví",
    "Putaendo",
    "Quillota",
    "Quilpué",
    "Quintero",
    "Rinconada",
    "San Antonio",
    "San Esteban",
    "San Felipe",
    "Santa María",
    "Santo Domingo",
    "Valparaíso",
    "Villa Alemana",
    "Viña del Mar",
    "Zapallar",
    ]
}

var regionElement = document.getElementById("edit-region");

var regionElementCallback = function () {
    var comunaElement = document.getElementById("edit-comuna");
    var value = regionElement.options[regionElement.selectedIndex].value;
    //var comunaskeys = Object.keys(comunas[value]);

    var length = comunaElement.options.length;
    for (i = length - 1; i >= 0; i--) {
        comunaElement.options[i] = NULL;
    }

    createOptions(comunas[value], comunaElement)
}

regionElementCallback();
regionElement.addEventListener("change", regionElementCallback);

function createOption(comunaElement, text, value)
{
    var opt = document.createElement('option');
    opt.value = value;
    opt.text = text;
    comunaElement.options.add(opt);
}

function createOptions(optionsArray, comunaElement)
{
    for (i = 0; i < optionsArray.length; i++) {
        createOption(comunaElement, optionsArray[i], optionsArray[i]);
    }
}

==> tiendaparamipyme-1.0.4.tar.gz: tiendaparamipyme/js/comunas.js <==
var comunas = {
    "Antofagasta": [
    "Antofagasta",
    "Calama",
    "María Elena",
    "Mejillones",
    "Ollagüe",
    "San Pedro de Atacama",
    "Sierra Gorda",
    "Taltal",
    "Tocopilla",
    ],
    "Araucanía": [
    "Angol",
    "Carahue",
    "Cholchol",
    "Collipulli",
    "Cunco",
    "Curacautín",
    "Curarrehue",
    "Ercilla",
    "Freire",
    "Galvarino",
    "Gorbea",
    "Lautaro",
    "Loncoche",
    "Lonquimay",
    "Los Sauces",
    "Lumaco",
    "Melipeuco",
    "Nueva Imperial",
    "Padre Las Casas",
    "Perquenco",
    "Pitrufquén",
    "Pucón",
    "Purén",
    "Renaico",
    "Saavedra",
    "Temuco",
    "Teodoro Schmidt",
    "Toltén",
    "Traiguén",
    "Victoria",
    "Vilcún",
    "Villarrica",
    ],
    "Arica y Parinacota": [
    "Arica",
    "Camarones",
    "General Lagos",
    "Putre",
    ],
    "Atacama": [
    "Alto del Carmen",
    "Caldera",
    "Chañaral",
    "Copiapó",
    "Diego de Almagro",
    "Freirina",
    "Huasco",
    "Tierra Amarilla",
    "Vallenar",
    ],
    "Aysén": [
    "Aysén",
    "Chile Chico",
    "Cisnes",
    "Cochrane",
    "Coyhaique",
    "Guaitecas",
    "Lago Verde",
    "O'Higgins",
    "Río Ibáñez",
    "Tortel",
    ],
    "Biobío": [
    "Alto Biobío",
    "Antuco",
    "Arauco",
    "Bulnes",
    "Cabrero",
    "Cañete",
    "Chiguayante",
    "Chillán",
    "Chillán Viejo",
    "Cobquecura",
    "Coelemu",
    "Coihueco",
    "Concepción",
    "Contulmo",
    "Coronel",
    "Curanilahue",
    "El Carmen",
    "Florida",
    "Hualpén",
    "Hualqui",
    "Laja",
    "Lebu",
    "Los Álamos",
    "Los Ángeles",
    "Lota",
    "Mulchén",
    "Nacimiento",
    "Negrete",
    "Ninhue",
    "Ñiquén",
    "Pemuco",
    "Penco",
    "Pinto",
    "Portezuelo",
    "Quilaco",
    "Quilleco",
    "Quillón",
    "Quirihue",
    "Ránquil",
    "San Carlos",
    "San Fabián",
    "San Ignacio",
    "San Nicolás",
    "San Pedro de la Paz",
    "San Rosendo",
    "Santa Bárbara",
    "Santa Juana",
    "Talcahuano",
    "Tirúa",
    "Tomé",
    "Treguaco",
    "Tucapel",
    "Yumbel",
    "Yungay"
    ],
    "Coquimbo": [
    "Andacollo",
    "Canela",
    "Combarbalá",
    "Coquimbo",
    "Illapel",
    "La Higuera",
    "La Serena",
    "Los Vilos",
    "Monte Patria",
    "Ovalle",
    "Paihuano",
    "Punitaqui",
    "Río Hurtado",
    "Salamanca",
    "Vicuña",
    ],
    "O'Higgins": [
    "Chépica",
    "Chimbarongo",
    "Codegua",
    "Coínco",
    "Coltauco",
    "Doñihue",
    "Graneros",
    "La Estrella",
    "Las Cabras",
    "Litueche",
    "Lolol",
    "Machalí",
    "Malloa",
    "Marchigüe",
    "Nancagua",
    "Navidad",
    "Olivar",
    "Palmilla",
    "Paredones",
    "Peralillo",
    "Peumo",
    "Pichidegua",
    "Pichilemu",
    "Placilla",
    "Pumanque",
    "Quinta de Tilcoco",
    "Rancagua",
    "Rengo",
    "Requínoa",
    "San Fernando",
    "San Francisco de Mostazal",
    "San Vicente de Tagua Tagua",
    "Santa Cruz",
    ],
    "Los Lagos": [
    "Ancud",
    "Calbuco",
    "Castro",
    "Chaitén",
    "Chonchi",
    "Cochamó",
    "Curaco de Vélez",
    "Dalcahue",
    "Fresia",
    "Frutillar",
    "Futaleufú",
    "Hualaihué",
    "Llanquihue",
    "Los Muermos",
    "Maullín",
    "Osorno",
    "Palena",
    "Puerto Montt",
    "Puerto Octay",
    "Puerto Varas",
    "Puqueldón",
    "Purranque",
    "Puyehue",
    "Queilén",
    "Quellón",
    "Quemchi",
    "Quinchao",
    "Río Negro",
    "San Juan de la Costa",
    "San Pablo",
    ],
    "Los Ríos": [
    "Corral",
    "Futrono",
    "La Unión",
    "Lago Ranco",
    "Lanco",
    "Los Lagos",
    "Máfil",
    "Mariquina",
    "Paillaco",
    "Panguipulli",
    "Río Bueno",
    "Valdivia",
    ],
    "Magallanes": [
    "Antártica",
    "Cabo de Hornos",
    "Laguna Blanca",
    "Natales",
    "Porvenir",
    "Primavera",
    "Punta Arenas",
    "Río Verde",
    "San Gregorio",
    "Timaukel",
    "Torres del Paine",
    ],
    "Maule": [
    "Cauquenes",
    "Chanco",
    "Colbún",
    "Constitución",
    "Curepto",
    "Curicó",
    "Empedrado",
    "Hualañé",
    "Licantén",
    "Linares",
    "Longaví",
    "Maule",
    "Molina",
    "Parral",
    "Pelarco",
    "Pelluhue",
    "Pencahue",
    "Rauco",
    "Retiro",
    "Río Claro",
    "Romeral",
    "Sagrada Familia",
    "San Clemente",
    "San Javier de Loncomilla",
    "San Rafael",
    "Talca",
    "Teno",
    "Vichuquén",
    "Villa Alegre",
    "Yerbas Buenas",
    ],
    "Región Metropolitana": [
    "Alhué",
    "Buin",
    "Calera de Tango",
    "Cerrillos",
    "Cerro Navia",
    "Colina",
    "Conchalí",
    "Curacaví",
    "El Bosque",
    "El Monte",
    "Estación Central",
    "Huechuraba",
    "Independencia",
    "Isla de Maipo",
    "La Cisterna",
    "La Florida",
    "La Granja",
    "La Pintana",
    "La Reina",
    "Lampa",
    "Las Condes",
    "Lo Barnechea",
    "Lo Espejo",
    "Lo Prado",
    "Macul",
    "Maipú",
    "María Pinto",
    "Melipilla",
    "Ñuñoa",
    "Padre Hurtado",
    "Paine",
    "Pedro Aguirre Cerda",
    "Peñaflor",
    "Peñalolén",
    "Pirque",
    "Providencia",
    "Pudahuel",
    "Puente Alto",
    "Quilicura",
    "Quinta Normal",
    "Recoleta",
    "Renca",
    "San Bernardo",
    "San Joaquín",
    "San José de Maipo",
    "San Miguel",
    "San Pedro",
    "San Ramón",
    "Santiago",
    "Talagante",
    "Tiltil",
    "Vitacura",
    ],
    "Tarapacá": [
    "Alto Hospicio",
    "Camiña",
    "Colchane",
    "Huara",
    "Iquique",
    "Pica",
    "Pozo Almonte",
    ],
    "Valparaíso": [
    "Algarrobo",
    "Cabildo",
    "Calle Larga",
    "Cartagena",
    "Casablanca",
    "Catemu",
    "Concón",
    "El Quisco",
    "El Tabo",
    "Hijuelas",
    "Isla de Pascua",
    "Juan Fernández",
    "La Calera",
    "La Cruz",
    "La Ligua",
    "Limache",
    "Llaillay",
    "Los Andes",
    "Nogales",
    "Olmué",
    "Panquehue",
    "Papudo",
    "Petorca",
    "Puchuncaví",
    "Putaendo",
    "Quillota",
    "Quilpué",
    "Quintero",
    "Rinconada",
    "San Antonio",
    "San Esteban",
    "San Felipe",
    "Santa María",
    "Santo Domingo",
    "Valparaíso",
    "Villa Alemana",
    "Viña del Mar",
    "Zapallar",
    ]
}

var regionElement = document.getElementById("edit-region");

var regionElementCallback = function () {
    var comunaElement = document.getElementById("edit-comuna");
    var value = regionElement.options[regionElement.selectedIndex].value;

    var length = comunaElement.options.length;
    for (i = length - 1; i >= 0; i--) {
        comunaElement.options[i] = null;
    }

    createOptions(comunas[value], comunaElement)
}

regionElementCallback();
regionElement.addEventListener("change", regionElementCallback);

function createOption(comunaElement, text, value)
{
    var opt = document.createElement('option');
    opt.value = value;
    opt.text = text;
    comunaElement.options.add(opt);
}

function createOptions(optionsArray, comunaElement)
{
    for (i = 0; i < optionsArray.length; i++) {
        createOption(comunaElement, optionsArray[i], optionsArray[i]);
    }
}
